==> qtcreator_4.5.2.orig.tar.xz: qt-creator-opensource-src-4.5.2/src/plugins/autotest/itestsettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "autotestconstants.h"
#include "itestframework.h"

#include <coreplugin/dialogs/ioptionspage.h>

namespace Autotest {
namespace Internal {

class IFrameworkSettings;

class ITestSettingsPage : public Core::IOptionsPage
{
public:
    explicit ITestSettingsPage(const ITestFramework *framework)
    {
        setId(Core::Id(Constants::SETTINGSPAGE_PREFIX).withSuffix(
                QString("%1.%2").arg(framework->priority()).arg(QLatin1String(framework->name()))));
        setCategory(Constants::AUTOTEST_SETTINGS_CATEGORY);
        setDisplayCategory(QCoreApplication::translate("AutoTest",
                                                       Constants::AUTOTEST_SETTINGS_TR));
    }

    virtual ~ITestSettingsPage() {}

private:
    void setId(Core::Id id)
    {
        Core::IOptionsPage::setId(id);
    }

    void setCategory(Core::Id category)
    {
        Core::IOptionsPage::setCategory(category);
    }

    void setDisplayCategory(const QString &displayCategory)
    {
        Core::IOptionsPage::setDisplayCategory(displayCategory);
    }
};

} // namespace Internal
} // namespace Autotest

==> qtcreator_4.11.0.orig.tar.xz: qt-creator-opensource-src-4.11.0/src/plugins/autotest/itestsettingspage.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "autotestconstants.h"
#include "itestframework.h"

#include <coreplugin/dialogs/ioptionspage.h>

namespace Autotest {

class IFrameworkSettings;

class ITestSettingsPage : public Core::IOptionsPage
{
public:
    explicit ITestSettingsPage(const ITestFramework *framework)
    {
        setId(Core::Id(Constants::SETTINGSPAGE_PREFIX).withSuffix(
                QString("%1.%2").arg(framework->priority()).arg(QLatin1String(framework->name()))));
        setCategory(Constants::AUTOTEST_SETTINGS_CATEGORY);
    }

    void finish() override {}

private:
    void setId(Core::Id id)
    {
        Core::IOptionsPage::setId(id);
    }

    void setCategory(Core::Id category)
    {
        Core::IOptionsPage::setCategory(category);
    }

    void setDisplayCategory(const QString &displayCategory)
    {
        Core::IOptionsPage::setDisplayCategory(displayCategory);
    }
};

} // namespace Autotest
